@@ -35,3 +35,28 @@ test_that("sig_noise() returns correct values", {
     expect_equal(97527)
 })
 
+test_that("entropy results in accurate info", {
+    sig_noise(raman_hdpe, 
+              metric = "entropy",
+              breaks = 10) |> 
+        round(2) |>
+        unname() |>
+        expect_equal(1.17)
+    
+    noise <- raman_hdpe
+    set.seed(10)
+    noise$spectra[[1]] <- runif(n = length(noise$spectra[[1]]))
+    
+    sig_noise(noise, metric = "entropy",
+              breaks = 10) |> 
+        round(2) |>
+        unname() |>
+        expect_equal(3.32)
+    
+    expect_true(sig_noise(raman_hdpe, 
+                          metric = "entropy",
+                          breaks = 10) |> 
+                    unname() < 
+                  sig_noise(noise, metric = "entropy",
+                                       breaks = 10) |> unname())
+})
